@@ -18,7 +18,7 @@ pub enum Rule {
     #[tag("Tokens")]
     Invalid(Tokens),
 
-    #[tag("*")]
+    #[tag("AtRule")]
     AtRule(AtRule),
 }
 
@@ -29,6 +29,18 @@ pub struct QualifiedRule {
     pub block: SimpleBlock,
 }
 
+#[ast_node]
+pub enum StyleBlock {
+    #[tag("AtRule")]
+    AtRule(AtRule),
+    #[tag("Declaration")]
+    Declaration(Declaration),
+    #[tag("QualifiedRule")]
+    QualifiedRule(QualifiedRule),
+    #[tag("Tokens")]
+    Invalid(Tokens),
+}
+
 #[ast_node("SimpleBlock")]
 pub struct SimpleBlock {
     pub span: Span,
@@ -44,6 +56,10 @@ pub enum ComponentValue {
     Value(Value),
     #[tag("DeclarationBlockItem")]
     DeclarationBlockItem(DeclarationBlockItem),
+    #[tag("Rule")]
+    Rule(Rule),
+    #[tag("StyleBlock")]
+    StyleBlock(StyleBlock),
 }
 
 #[ast_node]
